##
##  apache-sasl.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2015 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         apache-sasl
Summary:      Apache Extension: SASL
URL:          http://mod-authn-sasl.sourceforge.net/
Vendor:       Heiko Hund
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      Apache
Version:      1.2
Release:      20150112

#   list of sources
Source0:      http://switch.dl.sourceforge.net/mod-authn-sasl/mod_authn_sasl-%{version}.tar.bz2
Source1:      apache-sasl.conf
Patch0:       apache-sasl.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, gcc
PreReq:       OpenPKG, openpkg >= 20100101
BuildPreReq:  apache, apr
PreReq:       apache, apr

%description
    SASL-based authentication for the Apache webserver.

%track
    prog apache-sasl = {
        version   = %{version}
        url       = http://sourceforge.net/projects/mod-authn-sasl/files/
        regex     = mod_authn_sasl-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q -n mod_authn_sasl-%{version}
    %patch -p0

%build
    #   configure module
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lapr -laprutil" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-apxs=%{l_prefix}/sbin/apxs \
        --with-sasl2=%{l_prefix} \
        --with-sasl2-lib=%{l_prefix}/lib \
        --with-sasl2-includes=%{l_prefix}/include \
        --enable-shared \
        --disable-static

    #   build module
    %{l_make} %{l_mflags}

%install
    #   install module
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache
    %{l_shtool} install -c -m 755 \
        .libs/mod_authn_sasl.so \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache/mod_authn_sasl.so
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-sasl.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/apache/apache.d/apache-sasl.conf'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} apache status 2>/dev/null`
    [ ".$apache_active" = .yes ] && %{l_rc} apache restart
    exit 0

